Package: d3r
Type: Package
Title: 'd3.js' Utilities for R
Version: 1.1.0
Date: 2023-10-01
Authors@R: c(
      person(
        "Mike", "Bostock"
        , role = c("aut", "cph")
        , comment = "d3.js library in htmlwidgets/lib, http://d3js.org"
      ),
      person(
        "Kent", "Russell"
        , role = c("aut", "cre", "cph")
        , comment = "R interface"
        , email = "kent.russell@timelyportfolio.com"
      ),
      person(
        "Gregor", "Aisch"
        , role = c("aut", "cph")
        , comment = "d3-jetpack creator, https://github.com/gka/d3-jetpack"
      ),
      person(
        "Adam", "Pearce"
        , role = c("aut")
        , comment = "core contributor to d3-jetpack"
      ),
      person(
        "Ben", "Ortiz"
        , role = c("ctb")
      )
    )
Maintainer: Kent Russell <kent.russell@timelyportfolio.com>
URL: https://github.com/timelyportfolio/d3r
BugReports: https://github.com/timelyportfolio/d3r/issues
Description: Provides a suite of functions to help ease the use of 'd3.js' in R.
              These helpers include 'htmltools::htmlDependency' functions, hierarchy
              builders, and conversion tools for 'partykit', 'igraph,' 'table',
              and 'data.frame' R objects into the 'JSON' that 'd3.js' expects.
License: BSD_3_clause + file LICENSE
Encoding: UTF-8
Imports: dplyr, htmltools, tidyr (>= 0.8.3)
Suggests: httr, jsonlite, listviewer, purrr, testthat
Enhances: igraph, partykit, rpart, treemap, V8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-10-02 01:58:41 UTC; kentr
Author: Mike Bostock [aut, cph] (d3.js library in htmlwidgets/lib,
    http://d3js.org),
  Kent Russell [aut, cre, cph] (R interface),
  Gregor Aisch [aut, cph] (d3-jetpack creator,
    https://github.com/gka/d3-jetpack),
  Adam Pearce [aut] (core contributor to d3-jetpack),
  Ben Ortiz [ctb]
Repository: CRAN
Date/Publication: 2023-10-02 14:00:02 UTC
Built: R 4.2.0; ; 2023-10-02 15:45:43 UTC; unix
